# **How to use**
## **functions:**

### `bogosort(array)`

sorts the passed in `array` using the bogosort algorithm

[pseudocode](https://en.wikipedia.org/wiki/Bogosort#Description_of_the_algorithm)

### `multibogosort(array, numthreads)`

sorts the passed in array using the bogosort algorithm, but on multiple processes simultaneously. The number of processes can be specified with `numthreads`

<sub>**contributors**: sh6heer, jas.dzied</sub>

<sub>Licensed under GPL GNUv3</sub>
